==> cudo_compute-0.1.4.tar.gz: cudo_compute-0.1.4/out/docs/VM.md <==
# VM

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**active_state** | **str** |  | [optional] 
**boot_disk** | [**Disk**](Disk.md) |  | [optional] 
**boot_disk_size_gib** | **int** |  | [optional] 
**cpu_model** | **str** |  | [optional] 
**create_by** | **str** |  | [optional] 
**datacenter_id** | **str** |  | [optional] 
**external_ip_address** | **str** |  | [optional] 
**gpu_model** | **str** |  | [optional] 
**gpu_quantity** | **int** |  | [optional] 
**id** | **str** |  | [optional] 
**image_id** | **str** |  | [optional] 
**image_name** | **str** |  | [optional] 
**init_state** | **str** |  | [optional] 
**internal_ip_address** | **str** |  | [optional] 
**lcm_state** | **str** |  | [optional] 
**machine_type** | **str** |  | [optional] 
**memory** | **int** |  | [optional] 
**metadata** | **dict(str, str)** |  | [optional] 
**nics** | [**list[VMNIC]**](VMNIC.md) |  | [optional] 
**one_state** | **str** |  | [optional] 
**price_hr** | **float** |  | [optional] 
**private_image_id** | **str** |  | [optional] 
**public_image_id** | **str** |  | [optional] 
**public_image_name** | **str** |  | [optional] 
**public_ip_address** | **str** |  | [optional] 
**region_id** | **str** |  | [optional] 
**region_name** | **str** |  | [optional] 
**renewable_energy** | **bool** |  | [optional] 
**rules** | [**list[SecurityGroupRule]**](SecurityGroupRule.md) |  | [optional] 
**security_group_ids** | **list[str]** |  | [optional] 
**short_state** | **str** |  | [optional] 
**storage_disks** | [**list[Disk]**](Disk.md) |  | [optional] 
**vcpus** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> cudo_compute-0.3.0.tar.gz: cudo_compute-0.3.0/out/docs/VM.md <==
# VM

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**datacenter_id** | **str** |  | [optional] 
**machine_type** | **str** |  | [optional] 
**region_id** | **str** |  | [optional] 
**region_name** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**external_ip_address** | **str** |  | [optional] 
**internal_ip_address** | **str** |  | [optional] 
**public_ip_address** | **str** |  | [optional] 
**memory** | **int** |  | [optional] 
**cpu_model** | **str** |  | [optional] 
**vcpus** | **int** |  | [optional] 
**gpu_model** | **str** |  | [optional] 
**gpu_model_id** | **str** |  | [optional] 
**gpu_quantity** | **int** |  | [optional] 
**boot_disk_size_gib** | **int** |  | [optional] 
**price_hr** | **float** |  | [optional] 
**renewable_energy** | **bool** |  | [optional] 
**image_id** | **str** |  | [optional] 
**public_image_id** | **str** |  | [optional] 
**public_image_name** | **str** |  | [optional] 
**private_image_id** | **str** |  | [optional] 
**image_name** | **str** |  | [optional] 
**create_by** | **str** |  | [optional] 
**nics** | [**list[VMNIC]**](VMNIC.md) |  | [optional] 
**rules** | [**list[SecurityGroupRule]**](SecurityGroupRule.md) |  | [optional] 
**security_group_ids** | **list[str]** |  | [optional] 
**short_state** | **str** |  | [optional] 
**boot_disk** | [**Disk**](Disk.md) |  | [optional] 
**storage_disks** | [**list[Disk]**](Disk.md) |  | [optional] 
**metadata** | **dict(str, str)** |  | [optional] 
**state** | [**VmState**](VmState.md) |  | [optional] 
**create_time** | **datetime** |  | [optional] 
**expire_time** | **datetime** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
